## Summary

## search

### API search

ℹ️ Restriction: API searches do not support complex queries (yet)

```
colrev search --add colrev.colrev_project -p "https://github.com/CoLRev-Environment/example"
```

## Links
